@@ -28,12 +28,13 @@ bins_upper <- function(data, value, bins) {
 
   my_value <- rlang::enquo(value)
 
-  data %>%
+  data_max <-
+    data %>%
     dplyr::pull(!! my_value) %>%
     max() %>%
-    magrittr::add(1) %>%
-    purrr::prepend(bins)
+    magrittr::add(1)
 
+  c(bins, data_max)
 }
 
 
@@ -44,7 +45,7 @@ check_levels <- function(rfm_heatmap_data, column) {
   rfm_heatmap_data %>%
     dplyr::pull(!! my_column) %>%
     as.factor() %>%
-    forcats::fct_unique() %>%
+    levels() %>%
     as.vector() %>%
     as.integer()
 
@@ -63,13 +64,13 @@ modify_rfm <- function(rfm_heatmap_data, n_bins, check_levels) {
 
 #' @importFrom utils packageVersion menu install.packages
 check_suggests <- function(pkg) {
-  
+
   pkg_flag <- tryCatch(utils::packageVersion(pkg), error = function(e) NA)
-  
+
   if (is.na(pkg_flag)) {
-    
+
     msg <- message(paste0('\n', pkg, ' must be installed for this functionality.'))
-    
+
     if (interactive()) {
       message(msg, "\nWould you like to install it?")
       if (utils::menu(c("Yes", "No")) == 1) {
@@ -79,7 +80,7 @@ check_suggests <- function(pkg) {
       }
     } else {
       stop(msg, call. = FALSE)
-    } 
+    }
   }
 
 }
