@@ -7,7 +7,7 @@ test_that('output from rfm_bar_chart is as expected', {
   analysis_date <- lubridate::as_date('2006-12-31', tz = 'UTC')
   rfm_result <- rfm_table_order(rfm_data_orders, customer_id, order_date, revenue, analysis_date)
   p <- rfm_bar_chart(rfm_result)
-  vdiffr::expect_doppelganger('rfm barchart', p$plot)
+  vdiffr::expect_doppelganger('rfm barchart', p)
 
 })
 
@@ -18,7 +18,7 @@ test_that('output from rfm_rf_plot is as expected', {
   analysis_date <- lubridate::as_date('2006-12-31', tz = 'UTC')
   rfm_result <- rfm_table_order(rfm_data_orders, customer_id, order_date, revenue, analysis_date)
   p <- rfm_rf_plot(rfm_result)
-  vdiffr::expect_doppelganger('rfm rfplot', p$plot)
+  vdiffr::expect_doppelganger('rfm rfplot', p)
 
 })
 
@@ -29,7 +29,7 @@ test_that('output from rfm_rm_plot is as expected', {
   analysis_date <- lubridate::as_date('2006-12-31', tz = 'UTC')
   rfm_result <- rfm_table_order(rfm_data_orders, customer_id, order_date, revenue, analysis_date)
   p <- rfm_rm_plot(rfm_result)
-  vdiffr::expect_doppelganger('rfm rmplot', p$plot)
+  vdiffr::expect_doppelganger('rfm rmplot', p)
 
 })
 
@@ -40,7 +40,7 @@ test_that('output from rfm_fm_plot is as expected', {
   analysis_date <- lubridate::as_date('2006-12-31', tz = 'UTC')
   rfm_result <- rfm_table_order(rfm_data_orders, customer_id, order_date, revenue, analysis_date)
   p <- rfm_fm_plot(rfm_result)
-  vdiffr::expect_doppelganger('rfm fmplot', p$plot)
+  vdiffr::expect_doppelganger('rfm fmplot', p)
 
 })
 
@@ -53,7 +53,7 @@ test_that('output from rfm_heatmap is as expected', {
   rfm_result <- rfm_table_order(rfm_data_orders, customer_id, order_date,
     revenue, analysis_date)
   p <- rfm_heatmap(rfm_result)
-  vdiffr::expect_doppelganger('rfm heatmap', p$plot)
+  vdiffr::expect_doppelganger('rfm heatmap', p)
 
 })
 
@@ -65,7 +65,7 @@ test_that('output from rfm_histograms is as expected', {
   rfm_result <- rfm_table_order(rfm_data_orders, customer_id, order_date,
     revenue, analysis_date)
   p <- rfm_histograms(rfm_result)
-  vdiffr::expect_doppelganger('rfm histograms', p$plot)
+  vdiffr::expect_doppelganger('rfm histograms', p)
 
 })
 
@@ -77,7 +77,7 @@ test_that('output from rfm_order_dist is as expected', {
   rfm_result <- rfm_order <- rfm_table_order(rfm_data_orders, customer_id, order_date,
     revenue, analysis_date)
   p <- rfm_order_dist(rfm_result)
-  vdiffr::expect_doppelganger('rfm orderdist', p$plot)
+  vdiffr::expect_doppelganger('rfm orderdist', p)
 
 })
 
@@ -105,7 +105,7 @@ test_that('output from rfm_plot_median_recency is as expected', {
   skip_on_cran()
 
   p <- rfm_plot_median_recency(segments)
-  vdiffr::expect_doppelganger('rfm median recency', p$plot)
+  vdiffr::expect_doppelganger('rfm median recency', p)
 
 })
 
@@ -114,7 +114,7 @@ test_that('output from rfm_plot_median_frequency is as expected', {
   skip_on_cran()
 
   p <- rfm_plot_median_frequency(segments)
-  vdiffr::expect_doppelganger('rfm median frequency', p$plot)
+  vdiffr::expect_doppelganger('rfm median frequency', p)
 
 })
 
@@ -123,7 +123,7 @@ test_that('output from rfm_plot_median_monetary is as expected', {
   skip_on_cran()
 
   p <- rfm_plot_median_monetary(segments)
-  vdiffr::expect_doppelganger('rfm median monetary', p$plot)
+  vdiffr::expect_doppelganger('rfm median monetary', p)
 
 })
 
